<?php

/*
* @title		myFlickr php class
* @copyright	Copyright (C) 2011 Piotr Wooszyn. All rights reserved.
* @license		http://www.gnu.org/licenses/gpl-3.0.html GNU/GPL, see LICENSE.php
* @version 		1.1
* Release note to version 1.1 :
* - param passing rewriten 
* - new function photosSearch();
*
* http://www.piotrwoloszyn.com
* ptrwoloszyn@gmail.com
*
*/

defined( '_JEXEC' ) or die( 'Restricted access' );

class myFlickr{

	private $apiKey = "";
	private $last_error = "";
	private $_start;
	private $_end;

	function myFlickr($apiKey = "0")
	{
		$this->apiKey = $apiKey;
	}

	

	function perform($method,$args)
	{
		$params = $args;
		$params['api_key'] = $this->apiKey;
		$params['method'] = $method;
		$params['format'] = 'php_serial';
		$encoded_params = array();

		foreach ($params as $k => $v){
			$encoded_params[] = urlencode($k).'='.urlencode($v);
		}

		$url = "https://api.flickr.com/services/rest/?".implode('&', $encoded_params);
		$rsp = file_get_contents($url);
		$rsp_obj = unserialize($rsp);
		
		if($rsp_obj['stat'] == 'ok')
		{
			return $rsp_obj;
		}

		else{
			$this->last_error = 'Err '.$rsp_obj['code'].' : '.$rsp_obj['message'];
			if($rsp_obj['code'] == 2)
			{
				$this->last_error .= "<br/> To get your own flickr API key visit: <a href=\"http://www.flickr.com/services/apps/create/\" target=\"_blank\">http://www.flickr.com/services/apps/create/</a>";
			}
			
			return false;
		}
	}

	function groupsPoolsGetPhotos($params)
	{
		$method = 'flickr.groups.pools.getPhotos';
		$args = array();
		$args['group_id'] = isset($params['group_id']) ? $params['group_id'] : '0';
		$args['per_page'] = isset($params['per_page']) ? $params['per_page'] : '10';				
		$args['page'] = isset($params['page']) ? $params['page'] : '1';
		$args['extras'] = isset($params['extras']) ? $params['extras'] : '';	

		$result = $this->perform($method,$args);		
		return $result;	

	}

	

	function peopleGetPublicPhotos($params)
	{
		$method = 'flickr.people.getPublicPhotos';
		$args = array();
		$args['user_id'] = isset($params['user_id']) ? $params['user_id'] : '0';
		$args['per_page'] = isset($params['per_page']) ? $params['per_page'] : '10';				
		$args['page'] = isset($params['page']) ? $params['page'] : '1';
		$args['extras'] = isset($params['extras']) ? $params['extras'] : '';	

		$result = $this->perform($method,$args);		
		return $result;	
	}

	

	function photosetsGetPhotos($params)
	{

		$method = 'flickr.photosets.getPhotos';
		$args = array();
		$args['photoset_id'] = isset($params['photoset_id']) ? $params['photoset_id'] : '0';
		$args['per_page'] = isset($params['per_page']) ? $params['per_page'] : '10';				
		$args['page'] = isset($params['page']) ? $params['page'] : '1';
		$args['extras'] = isset($params['extras']) ? $params['extras'] : '';	
	
		$result = $this->perform($method,$args);		
		return $result;
	}

	
	function photosSearch($params)
	{
		$method = 'flickr.photos.search';
		$args = array();
		
		if(isset($params['group_id']) && !empty($params['group_id']))
		{
			$args['group_id'] = $params['group_id'];
		}

		if(isset($params['tags']) && !empty($params['tags']))
		{
			$args['tags'] = str_replace("|",",",$params['tags']);
		}		

		if(isset($params['tag_mode']) && !empty($params['tag_mode']))
		{
			$args['tag_mode'] = $params['tag_mode'];
		}

		if(isset($params['text']) && !empty($params['text']))
		{
			$args['text'] = $params['text'];
		}

		if(isset($params['sort']) && !empty($params['sort']))
		{
			$args['sort'] = $params['sort'];
		}		
		
		if(isset($params['min_upload_date']) && !empty($params['min_upload_date']))
		{
			$args['min_upload_date'] = $params['min_upload_date'];
		}

		if(isset($params['max_upload_date']) && !empty($params['max_upload_date']))
		{
			$args['max_upload_date'] = $params['max_upload_date'];
		}		

		if(isset($params['min_taken_date']) && !empty($params['min_taken_date']))
		{
			$args['min_taken_date'] = $params['min_taken_date'];
		}

		if(isset($params['max_taken_date']) && !empty($params['max_taken_date']))
		{
			$args['max_taken_date'] = $params['max_taken_date'];
		}
		
		$args['per_page'] = isset($params['per_page']) ? $params['per_page'] : '10';				
		$args['page'] = isset($params['page']) ? $params['page'] : '1';
		$args['extras'] = isset($params['extras']) ? $params['extras'] : '';	
	
		$result = $this->perform($method,$args);		

		return $result;
		
	}	
	

	function photosGetRecent($params)
	{
		$method = 'flickr.photos.getRecent';
		$args = array();
		$args['per_page'] = isset($params['per_page']) ? $params['per_page'] : '10';				
		$args['page'] = isset($params['page']) ? $params['page'] : '1';
		$args['extras'] = isset($params['extras']) ? $params['extras'] : '';

		$result = $this->perform($method,$args);		
		return $result;
	}

	

	function getLastError()
	{
		return $this->last_error;
	}

}